summaryrefslogtreecommitdiff
path: root/src/bin/pg_rewind
diff options
context:
space:
mode:
authorNoah Misch <noah@leadboat.com>2016-02-10 20:34:57 -0500
committerNoah Misch <noah@leadboat.com>2016-02-10 20:36:21 -0500
commit2dcaebea079d6e3c2c78bbf3b0948bf5ef707e21 (patch)
tree10b8c5810abe8293aad8f13c74cfd8bad156a3c9 /src/bin/pg_rewind
parent725f0ce29690b7e98d18290c9ab69b7a2bab3715 (diff)
downloadpostgresql-2dcaebea079d6e3c2c78bbf3b0948bf5ef707e21.tar.gz
In pg_rewind test suite, triple promote timeout to 90s.
Thirty seconds was not consistently enough for promotion to complete on buildfarm members sungazer and tern. Experiments suggest 43s would have been enough. Back-patch to 9.5, where pg_rewind was introduced.
Diffstat (limited to 'src/bin/pg_rewind')
-rw-r--r--src/bin/pg_rewind/RewindTest.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/bin/pg_rewind/RewindTest.pm b/src/bin/pg_rewind/RewindTest.pm
index d23ad2d00c..426bd6e5cf 100644
--- a/src/bin/pg_rewind/RewindTest.pm
+++ b/src/bin/pg_rewind/RewindTest.pm
@@ -130,7 +130,7 @@ sub poll_query_until
{
my ($query, $connstr) = @_;
- my $max_attempts = 30;
+ my $max_attempts = 90;
my $attempts = 0;
my ($stdout, $stderr);
@@ -151,7 +151,7 @@ sub poll_query_until
$attempts++;
}
# The query result didn't change in 30 seconds. Give up. Print the stderr
# from the last attempt, hopefully that's useful for debugging.
diag $stderr;
return 0;
@@ -151,7 +151,7 @@ sub poll_query_until
$attempts++;
}
- # The query result didn't change in 30 seconds. Give up. Print the stderr
+ # The query result didn't change in 90 seconds. Give up. Print the stderr
# from the last attempt, hopefully that's useful for debugging.
diag $stderr;